@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC Email Domain commands
 ##
-## Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -46,7 +46,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -97,6 +97,7 @@ sub add_starting_block
  $mes->line('1g',$rd->{auth_code}) if ($action=~m/^[CD]$/ && Net::DRI::Util::has_key($rd,'auth_code') && $rd->{auth_code}); ## authorization code for reserved domain names
 
  $mes->line('2a',$domain);
+ return;
 }
 
 sub create
@@ -143,6 +144,7 @@ sub create
 
  add_all_ns($domain,$mes,$rd->{ns}) if Net::DRI::Util::has_ns($rd);
  add_installation($mes,$rd);
+ return;
 }
 
 sub add_company_info
@@ -164,6 +166,7 @@ sub add_company_info
   $mes->line('3n',$jo->{page})             if (exists($jo->{page})             && $jo->{page});
  }
  $mes->line('3p',$co->trademark()) if $co->trademark();
+ return;
 }
 
 
@@ -177,6 +180,7 @@ sub add_installation
  ## S = standard = fax need to be sent, Default = E = Express = no fax
  my $form=(Net::DRI::Util::has_key($rd,'form_type') && $rd->{form_type}=~m/^[SE]$/)? $rd->{form_type} : 'E';
  $mes->line('9a',$form);
+ return;
 }
 
 sub add_owner_info
@@ -202,6 +206,7 @@ sub add_owner_info
   $mes->line('3u',format_tel($co->fax())) if $co->fax();
   $mes->line('3v',$co->email());
  }
+ return;
 }
 
 sub add_maintainer_disclose
@@ -211,6 +216,7 @@ sub add_maintainer_disclose
  $mes->line('3y',$maintainer);
  Net::DRI::Exception::usererr_insufficient_parameters('disclose option is mandatory if no nichandle') unless ($co->disclose());
  $mes->line('3z',$co->disclose());
+ return;
 }
 
 sub add_admin_contact
@@ -218,6 +224,7 @@ sub add_admin_contact
  my ($mes,$cs)=@_;
  my $co=$cs->get('admin');
  $mes->line('4a',$co->srid().'-FRNIC') if (Net::DRI::Util::isa_contact($co) && $co->srid());
+ return;
 }
 
 sub add_tech_contacts
@@ -228,6 +235,7 @@ sub add_tech_contacts
  $mes->line('5a',$co[0].'-FRNIC');
  $mes->line('5c',$co[1].'-FRNIC') if $co[1];
  $mes->line('5e',$co[2].'-FRNIC') if $co[2];
+ return;
 }
 
 sub add_all_ns
@@ -244,6 +252,7 @@ sub add_all_ns
  add_one_ns($mes,$ns,6,$domain,'7i','7j') if ($nsc >= 6);
  add_one_ns($mes,$ns,7,$domain,'7k','7l') if ($nsc >= 7);
  add_one_ns($mes,$ns,8,$domain,'7m','7n') if ($nsc >= 8);
+ return;
 }
 
 sub add_one_ns
@@ -254,18 +263,20 @@ sub add_one_ns
  $mes->line($l1,$g[0]); ## name
  return unless ($g[0]=~m/\S+\.${domain}/i || (lc($g[0]) eq lc($domain)));
  $mes->line($l2,join(' ',@{$g[1]},@{$g[2]})); ## nameserver in domain, we add IPs
+ return;
 }
 
-sub delete
+sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($a,$domain,$rd)=@_;
  my $mes=$a->message();
 
  add_starting_block('S',$domain,$mes,$rd);
  add_installation($mes,$rd);
+ return;
 }
 
-sub update
+sub update ## no critic (Subroutines::RequireFinalReturn)
 {
  my ($a,$domain,$todo,$rd)=@_;
  my $mes=$a->message();
@@ -335,7 +346,7 @@ sub trade
   Net::DRI::Exception::usererr_insufficient_parameters('authInfo is mandatory') unless Net::DRI::Util::has_auth($rd);
   $mes->line('2z',$rd->{auth}->{pw});
  }
-
+ return;
 }
 
 sub transfer_request
@@ -367,6 +378,7 @@ sub transfer_request
  add_tech_contacts($mes,$cs); ##  tech contacts mandatory
  add_all_ns($domain,$mes,$rd->{ns}) if Net::DRI::Util::has_ns($rd);
  add_installation($mes,$rd);
+ return;
 }
 
 ####################################################################################################
