@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Contact EPP extension commands
 ##
-## Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -15,6 +15,7 @@
 package Net::DRI::Protocol::EPP::Extensions::CAT::Contact;
 
 use strict;
+use warnings;
 
 =pod
 
@@ -44,7 +45,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -101,6 +102,7 @@ sub create
 
  my $eid=build_command_extension($mes,$epp,'cx:create');
  $mes->command_extension($eid,\@n);
+ return;
 }
 
 sub update
@@ -116,6 +118,7 @@ sub update
 
  my $eid=build_command_extension($mes,$epp,'cx:update');
  $mes->command_extension($eid,['cx:chg',@n]);
+ return;
 }
 
 sub info_parse
@@ -135,6 +138,7 @@ sub info_parse
  $s->maintainer($el->get_node(1)->getFirstChild()->getData()) if $el;
  $el=$infdata->getChildrenByTagNameNS($mes->ns('puntcat_contact'),'sponsorEmail');
  $s->email_sponsor($el->get_node(1)->getFirstChild()->getData()) if $el;
+ return;
 }
 
 ####################################################################################################
