@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Registrar EPP extension notifications
 ## (introduced in release 5.6 october 2008)
 ##
-## Copyright (c) 2009,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009,2012 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -76,6 +76,7 @@ sub setup
 {
  my ($class,$po,$version)=@_;
  $po->ns({ 'poll' => [ 'http://www.eurid.eu/xml/epp/poll-1.0','poll-1.0.xsd' ] });
+ return;
 }
 
 ####################################################################################################
@@ -90,7 +91,6 @@ sub parse
  return unless defined $poll;
 
  my %n;
- my ($action,$returncode,$level);
  foreach my $el (Net::DRI::Util::xml_list_children($poll))
  {
   my ($name,$c)=@$el;
@@ -100,15 +100,20 @@ sub parse
   }
  }
 
- $rinfo->{session}->{notification}=\%n;
  if ($n{context}=~m/^(?:DOMAIN|TRANSFER)$/)
  {
   $oname=$n{object};
+  $rinfo->{domain}->{$oname}->{context}=$n{context};
   $rinfo->{domain}->{$oname}->{notification_code}=$n{code};
   $rinfo->{domain}->{$oname}->{action}=$n{action};
   $rinfo->{domain}->{$oname}->{detail}=$n{detail} if exists $n{detail};
+  $rinfo->{domain}->{$oname}->{context}=$n{context};
   $rinfo->{domain}->{$oname}->{exist}=1;
+ } else
+ {
+  $rinfo->{session}->{notification}=\%n;
  }
+ return;
 }
 
 ####################################################################################################
