@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .UK EPP Account commands
 ##
-## Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -121,6 +121,7 @@ sub info
  my $mes=$epp->message();
  my @d=build_command($mes,'info',$c);
  $mes->command_body(\@d);
+ return;
 }
 
 sub info_parse
@@ -133,6 +134,7 @@ sub info_parse
  return unless defined $infdata;
 
  parse_infdata($po,$mes,$infdata,$oname,$rinfo);
+ return;
 }
 
 sub parse_infdata
@@ -227,6 +229,7 @@ sub parse_addr
  }
 
  $c->street(\@street);
+ return;
 }
 
 sub build_addr
@@ -304,9 +307,10 @@ sub update
  my @d=build_command($mes,'update',$c);
  push @d,add_account_data($mes,$cs,1);
  $mes->command_body(\@d);
+ return;
 }
 
-sub fork
+sub fork ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($epp,$c,$rh)=@_;
  Net::DRI::Exception::usererr_invalid_parameters('For account fork, a domains key must be there with a ref array of domain names to fork') unless (Net::DRI::Util::has_key($rh,'domains') && (ref($rh->{domains}) eq 'ARRAY'));
@@ -322,6 +326,7 @@ sub fork
   push @d,['account:domain-name',$d];
  }
  $mes->command_body(\@d);
+ return;
 }
 
 sub parse_credata
@@ -370,6 +375,7 @@ sub fork_parse
  my $roid=parse_credata($mes,$credata,$po,$cs,$rinfo);
  $rinfo->{account}->{$roid}->{action}='fork';
  $rinfo->{account}->{$oname}->{fork_to}=$roid if defined($oname); ## roid not mandatory during fork call
+ return;
 }
 
 sub merge
@@ -400,6 +406,7 @@ sub merge
  }
 
  $mes->command_body(\@d);
+ return;
 }
 
 ####################################################################################################
@@ -426,6 +433,7 @@ sub list_domains
  }
  push @d,['domain:fields','none']; ## with that we get only domain names back, if 'all' instead we get full infData for each domain, as in domain_info reply
  $mes->command_body(\@d);
+ return;
 }
 
 sub list_domains_parse
@@ -438,6 +446,7 @@ sub list_domains_parse
  my $list=$mes->get_response('domain','listData');
  $rinfo->{account}->{domains}->{action}='list';
  $rinfo->{account}->{domains}->{list}=defined $list ? [ map { $_->textContent() } $list->getChildrenByTagNameNS($mes->ns('domain'),'name') ] : [];
+ return;
 }
 
 ####################################################################################################
