@@ -1,6 +1,6 @@
 ## Domain Registry Interface, RRI Message
 ##
-## Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
+## Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -55,7 +55,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2007-2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -125,14 +125,14 @@ sub as_string
 
  $attr = '' unless (defined($attr));
  $attr = ' ' . join(' ', map { $_ . '="' . $attr->{$_} . '"' }
-	keys (%{$attr})) if (ref($attr) eq 'HASH');
+	sort { $a cmp $b } keys (%{$attr})) if (ref($attr) eq 'HASH');
 
  if (defined($ns))
  {
   if (ref($ns) eq 'HASH')
   {
    $ens .= ' ' . join(' ', map { 'xmlns:' . $_ . '="' . $ns->{$_} . '"' }
-	keys(%{$ns}));
+	sort { $a cmp $b } keys(%{$ns}));
    $cmd = $type . ':' . $cmd;
   }
   else
@@ -255,6 +255,8 @@ sub parse
   my @cltrid = $res->getElementsByTagNameNS($trNS, 'ctid');
   $self->cltrid($cltrid[0]->firstChild()->getData());
  }
+
+ return;
 }
 
 ####################################################################################################
